import { useRef } from 'react';
import { useLoad, useUnload } from 'react-native-lifecycle';
import { useNavigation } from '@react-navigation/native';
import { BackHandler } from 'react-native';
/**
 *  页面手势返回
 * @param {boolean} enabled 是否启用
 * @public
 */
export default (enabled) => {
    const enabledRef = useRef(enabled);
    const navigation = useNavigation();
    const _onHardwareBackPress = () => {
        return !enabledRef.current;
    };
    const setEnabled = (enabled) => {
        enabledRef.current = enabled;
        navigation.setOptions({
            gestureEnabled: enabled,
        });
    };
    useLoad(() => {
        navigation.setOptions({
            gestureEnabled: enabled,
        });
        BackHandler.addEventListener('hardwareBackPress', _onHardwareBackPress);
    });
    useUnload(() => {
        BackHandler.removeEventListener('hardwareBackPress', _onHardwareBackPress);
    });
    return {
        setEnabled,
    };
};
